@@ -344,7 +344,8 @@
       INTEGER            BLOCK_CYCLIC_2D, CSRC_, CTXT_, DLEN_, DTYPE_,
      $                   LLD_, MB_, M_, NB_, N_, RSRC_
       DOUBLE PRECISION   ZERO, ONE
-      PARAMETER          ( TOP = '1-Tree',
+      !PARAMETER          ( TOP = '1-Tree',
+      PARAMETER          ( TOP = '1',
      $                     BLOCK_CYCLIC_2D = 1, DLEN_ = 9, DTYPE_ = 1,
      $                     CTXT_ = 2, M_ = 3, N_ = 4, MB_ = 5, NB_ = 6,
      $                     RSRC_ = 7, CSRC_ = 8, LLD_ = 9,
